import {BaseReader}                     from './base.reader';
import {IReaderConfiguration}           from "../models/reader.configuration";
import {IBarcodeValue, BarcodeValue}    from '../models';
import { AIM_CODES } from '../config/aim-codes';
import { AimParser } from '../utils/aim-parser';

const REG: any = /^[A-Z0-9* \-$%.+\/]{1,43}$/;
const SYMBOLOGY: string = 'code_39';
//todo this should probably eventually move into parent app
const defaultConfig = {
				values: [
					{
						valueType: "documentType",
						start: 0,
						length: 1
					},
					{
						valueType: "companyId",
						start: -4,
						length: 2
					},
					{
						valueType: "locationId",
						start: -2,
						length: 2
					},
					{
						valueType: "documentId",
						start: 1,
						length: 9
					}
				]
			} as IReaderConfiguration;

export class Code39Reader extends BaseReader {

	constructor(readerConfig?: IReaderConfiguration) {
		let config = readerConfig || defaultConfig;
		super(SYMBOLOGY, REG, config);
	}

	public validate(value: string): boolean {
		let aimPrefix = value.indexOf(AIM_CODES.CODE39);
		return aimPrefix === 0 && super.validate(AimParser.parseAimCode(this.symbology, value));
	}


	// protected static valueIndex(index, length): number {
	// 	return (index >= 0) ? index : length + index;
	// }

	public decode(value: string): IBarcodeValue {
		let result = new BarcodeValue(this.symbology, value);
		try {
			this.tryValidate(value);
			// result.values = this.parseValues(value);
			result.values = AimParser.parseAimCode(this.symbology, value);
		} catch (ex) {
			result.success = false;
			result.errorMessage = ex;
		}
		return result;
	}

	// protected parseValues(value: string): Object {
	// 	var result = {};
	// 	this._readerConfig.values.forEach(function (data: IEmbeddedData) {
	// 		result[data.valueType] = value.substr(Code39Reader.valueIndex(data.start, value.length), data.length);
	// 	});
	// 	return result;
	// }
}

